==> aroundme-0_4_0.zip: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/my_blog.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_blog'] = 							"blog";
$lang['hdr_images'] = 							"images";


//A HREF TAGS (links)
$lang['href_add_blog'] = 						"Add blog article";
$lang['href_list'] = 							"List";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blogs available.";


//BODY TEXT
$lang['txt_publish_node'] =						"everyone";
$lang['txt_publish_node_help'] =				"will appear in Splash and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your blog to be? You can publish to just your friends, wider degrees of aquantances or the Splash magazine page.";
$lang['txt_blog_body'] =						"Blog";
$lang['txt_blog_body_help'] =					"The main article. Remeber, if you are going to spend more than 10 minutes here, copy the article into a word process, take you time, then copy and paste it back here. otherwise you could loose your work!";
$lang['txt_blog_title'] =						"Blog title";
$lang['txt_blog_title_help'] =					"The title of your diary article. Use up to 250 characters.";
$lang['txt_blog_synopsis'] =					"Blog synopsis";
$lang['txt_blog_synopsis_help'] =				"The diary articles description, or synopsis. Write a simple synopsis of this diary article.";
$lang['txt_genre'] = 							"Genre";
$lang['txt_genre_help'] = 						"Select a genre that your article fits best. Remember that publishing to all and selecting a genre will put the article in the 'highlights' section of the site.";
$lang['txt_other'] =							"other";
$lang['txt_language'] = 						"language";
$lang['txt_language_help'] = 					"Language of this journal.";
$lang['txt_images_help'] = 						"These are the images available to the group. Select one if you want it to appear next to this item.";
$lang['txt_allow_comments'] =					"check to allow comments against this item";

?>

==> aroundme_0_4_2.zip: aroundme_0_4_2/www/aroundme_0_4_2/language/1/am_default/my_blog.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'my_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_blog'] = 							"blog";
$lang['hdr_images'] = 							"images";


//A HREF TAGS (links)
$lang['href_add_blog'] = 						"Add blog article";
$lang['href_list'] = 							"List";


//ERRORS
$lang['err_no_blogs'] = 						"Sorry, you have no blogs available.";


//BODY TEXT
$lang['txt_publish_level'] =					"everyone";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_public_help'] =				"Item will be submitted to web site editor and can be viewed by anyone.";
$lang['txt_publish_help'] =						"How wide do you want the audience of your blog to be? You can publish to just your friends, wider degrees of aquantances or the Splash magazine page.";
$lang['txt_blog_body'] =						"Blog";
$lang['txt_blog_body_help'] =					"The main article. Remeber, if you are going to spend more than 10 minutes here, copy the article into a word process, take you time, then copy and paste it back here. otherwise you could loose your work!";
$lang['txt_blog_title'] =						"Blog title";
$lang['txt_blog_title_help'] =					"The title of your diary article. Use up to 250 characters.";
$lang['txt_blog_synopsis'] =					"Blog synopsis";
$lang['txt_blog_synopsis_help'] =				"The diary articles description, or synopsis. Write a simple synopsis of this diary article.";
$lang['txt_genre'] = 							"Genre";
$lang['txt_genre_help'] = 						"Select a genre that your article fits best. Remember that publishing to all and selecting a genre will put the article in the 'highlights' section of the site.";
$lang['txt_other'] =							"other";
$lang['txt_language'] = 						"language";
$lang['txt_language_help'] = 					"Language of this journal.";
$lang['txt_images_help'] = 						"These are the images available to the group. Select one if you want it to appear next to this item.";
$lang['txt_allow_comments'] =					"check to allow comments against this item";

?>
